@@ -23,17 +23,17 @@ struct type_emissions {
 	struct list_head fwd_decls;   /* struct class entries */
 };
 
-void type_emissions__init(struct type_emissions *self);
+void type_emissions__init(struct type_emissions *temissions);
 
-int ftype__emit_definitions(struct ftype *self, struct cu *cu,
+int ftype__emit_definitions(struct ftype *ftype, struct cu *cu,
 			    struct type_emissions *emissions, FILE *fp);
-int type__emit_definitions(struct tag *self, struct cu *cu,
+int type__emit_definitions(struct tag *tag, struct cu *cu,
 			   struct type_emissions *emissions, FILE *fp);
 int type__emit_fwd_decl(struct type *ctype, const struct cu *cu,
 			struct type_emissions *emissions, FILE *fp);
-void type__emit(struct tag *tag_self, struct cu *cu,
+void type__emit(struct tag *tag_type, struct cu *cu,
 		const char *prefix, const char *suffix, FILE *fp);
-struct type *type_emissions__find_definition(const struct type_emissions *self,
+struct type *type_emissions__find_definition(const struct type_emissions *temissions,
 					     const struct cu *cu,
 					     const char *name);
 
