@@ -13,37 +13,37 @@
 #include "dwarves_reorganize.h"
 #include "dwarves.h"
 
-void class__subtract_offsets_from(struct class *self,
+void class__subtract_offsets_from(struct class *class,
 				  struct class_member *from,
 				  const uint16_t size)
 {
 	struct class_member *member =
-		list_prepare_entry(from, class__tags(self), tag.node);
+		list_prepare_entry(from, class__tags(class), tag.node);
 
-	list_for_each_entry_continue(member, class__tags(self), tag.node)
+	list_for_each_entry_continue(member, class__tags(class), tag.node)
 		if (member->tag.tag == DW_TAG_member)
 			member->byte_offset -= size;
 
-	if (self->padding != 0) {
+	if (class->padding != 0) {
 		struct class_member *last_member =
-					type__last_member(&self->type);
-		const ssize_t new_padding = (class__size(self) -
+					type__last_member(&class->type);
+		const ssize_t new_padding = (class__size(class) -
 					     (last_member->byte_offset +
 					      last_member->byte_size));
 		if (new_padding > 0)
-			self->padding = new_padding;
+			class->padding = new_padding;
 		else
-			self->padding = 0;
+			class->padding = 0;
 	}
 }
 
-void class__add_offsets_from(struct class *self, struct class_member *from,
+void class__add_offsets_from(struct class *class, struct class_member *from,
 			     const uint16_t size)
 {
 	struct class_member *member =
-		list_prepare_entry(from, class__tags(self), tag.node);
+		list_prepare_entry(from, class__tags(class), tag.node);
 
-	list_for_each_entry_continue(member, class__tags(self), tag.node)
+	list_for_each_entry_continue(member, class__tags(class), tag.node)
 		if (member->tag.tag == DW_TAG_member)
 			member->byte_offset += size;
 }
@@ -53,14 +53,14 @@ void class__add_offsets_from(struct class *self, struct class_member *from,
  * to lazy to do class__remove_member properly, adjusting alignments and
  * holes as we go removing fields. Ditto for class__add_offsets_from.
  */
-void class__fixup_alignment(struct class *self, const struct cu *cu)
+void class__fixup_alignment(struct class *class, const struct cu *cu)
 {
 	struct class_member *pos, *last_member = NULL;
 	size_t power2;
 
-	type__for_each_data_member(&self->type, pos) {
+	type__for_each_data_member(&class->type, pos) {
 		if (last_member == NULL && pos->byte_offset != 0) { /* paranoid! */
-			class__subtract_offsets_from(self, pos,
+			class__subtract_offsets_from(class, pos,
 						     (pos->byte_offset -
 						      pos->byte_size));
 			pos->byte_offset = 0;
@@ -71,10 +71,10 @@ void class__fixup_alignment(struct class *self, const struct cu *cu)
 
 			last_member->hole -= dec;
 			if (last_member->hole == 0)
-				--self->nr_holes;
+				--class->nr_holes;
 			pos->byte_offset -= dec;
-			self->type.size -= dec;
-			class__subtract_offsets_from(self, pos, dec);
+			class->type.size -= dec;
+			class__subtract_offsets_from(class, pos, dec);
 		} else for (power2 = cu->addr_size; power2 >= 2; power2 /= 2) {
 			const size_t remainder = pos->byte_offset % power2;
 
@@ -84,18 +84,18 @@ void class__fixup_alignment(struct class *self, const struct cu *cu)
 				if (last_member->hole >= remainder) {
 					last_member->hole -= remainder;
 					if (last_member->hole == 0)
-						--self->nr_holes;
+						--class->nr_holes;
 					pos->byte_offset -= remainder;
-					class__subtract_offsets_from(self, pos, remainder);
+					class__subtract_offsets_from(class, pos, remainder);
 				} else {
 					const size_t inc = power2 - remainder;
 
 					if (last_member->hole == 0)
-						++self->nr_holes;
+						++class->nr_holes;
 					last_member->hole += inc;
 					pos->byte_offset += inc;
-					self->type.size += inc;
-					class__add_offsets_from(self, pos, inc);
+					class->type.size += inc;
+					class__add_offsets_from(class, pos, inc);
 				}
 			}
 		}
@@ -105,7 +105,7 @@ void class__fixup_alignment(struct class *self, const struct cu *cu)
 
 	if (last_member != NULL) {
 		struct class_member *m =
-		 type__find_first_biggest_size_base_type_member(&self->type, cu);
+		 type__find_first_biggest_size_base_type_member(&class->type, cu);
 		size_t unpadded_size = last_member->byte_offset + last_member->byte_size;
 		size_t m_size = m->byte_size, remainder;
 
@@ -115,8 +115,8 @@ void class__fixup_alignment(struct class *self, const struct cu *cu)
 
 		remainder = unpadded_size % m_size;
 		if (remainder != 0) {
-			self->padding = m_size - remainder;
-			self->type.size = unpadded_size + self->padding;
+			class->padding = m_size - remainder;
+			class->type.size = unpadded_size + class->padding;
 		}
 	}
 }
@@ -198,7 +198,7 @@ static struct class_member *
 #if 0
 	/*
 	 * FIXME: Handle the case where the bit padding is on the same bitfield
-	 * that we're looking, i.e. we can't combine a bitfield with itself,
+	 * that we're looking, i.e. we can't combine a bitfield with itclass,
 	 * perhaps we should tag bitfields with a sequential, clearly marking
 	 * each of the bitfields in advance, so that all the algoriths that
 	 * have to deal with bitfields, moving them around, demoting, etc, can
@@ -351,7 +351,7 @@ static void class__move_member(struct class *class, struct class_member *dest,
 
 	if (verbose > 1) {
 		class__find_holes(class);
-		class__fprintf(class, cu, NULL, fp);
+		class__fprintf(class, cu, fp);
 		fputc('\n', fp);
 	}
 }
@@ -428,7 +428,7 @@ static void class__move_bit_member(struct class *class, const struct cu *cu,
 	dest->hole = 0;
 	if (verbose > 1) {
 		class__find_holes(class);
-		class__fprintf(class, cu, NULL, fp);
+		class__fprintf(class, cu, fp);
 		fputc('\n', fp);
 	}
 }
@@ -533,7 +533,7 @@ static int class__demote_bitfields(struct class *class, const struct cu *cu,
 
 		size = member->byte_size;
 	    	bytes_needed = (current_bitfield_size + 7) / 8;
-		bytes_needed = roundup(bytes_needed, 2);
+		bytes_needed = roundup_pow_of_two(bytes_needed);
 		if (bytes_needed == size)
 			continue;
 
@@ -577,7 +577,7 @@ static int class__demote_bitfields(struct class *class, const struct cu *cu,
 			--class->nr_bit_holes;
 		if (verbose > 1) {
 			class__find_holes(class);
-			class__fprintf(class, cu, NULL, fp);
+			class__fprintf(class, cu, fp);
 			fputc('\n', fp);
 		}
 	}
@@ -636,7 +636,7 @@ static int class__demote_bitfields(struct class *class, const struct cu *cu,
 			some_was_demoted = 1;
 			if (verbose > 1) {
 				class__find_holes(class);
-				class__fprintf(class, cu, NULL, fp);
+				class__fprintf(class, cu, fp);
 				fputc('\n', fp);
 			}
 		}
@@ -671,15 +671,15 @@ restart:
 	}
 }
 
-static void class__fixup_bitfield_types(struct class *self,
+static void class__fixup_bitfield_types(struct class *class,
 					struct class_member *from,
 					struct class_member *to_before,
 					uint16_t type)
 {
 	struct class_member *member =
-		list_prepare_entry(from, class__tags(self), tag.node);
+		list_prepare_entry(from, class__tags(class), tag.node);
 
-	list_for_each_entry_from(member, class__tags(self), tag.node) {
+	list_for_each_entry_from(member, class__tags(class), tag.node) {
 		if (member->tag.tag != DW_TAG_member)
 			continue;
 		if (member == to_before)
@@ -712,13 +712,13 @@ static void class__fixup_bitfield_types(struct class *self,
  * the reorganizing routines we just do the demotion ourselves, fixing up the
  * sizes.
 */
-static void class__fixup_member_types(struct class *self, const struct cu *cu,
+static void class__fixup_member_types(struct class *class, const struct cu *cu,
 				      const uint8_t verbose, FILE *fp)
 {
 	struct class_member *pos, *bitfield_head = NULL;
 	uint8_t fixup_was_done = 0;
 
-	type__for_each_data_member(&self->type, pos) {
+	type__for_each_data_member(&class->type, pos) {
 		/*
 		 * Is this bitfield member?
 		 */
@@ -738,7 +738,29 @@ static void class__fixup_member_types(struct class *self, const struct cu *cu,
 			const uint16_t real_size = (pos->byte_offset -
 						  bitfield_head->byte_offset);
 			const size_t size = bitfield_head->byte_size;
-			if (real_size != size) {
+			/*
+			 * Another case:
+struct irq_cfg {
+	struct irq_pin_list *      irq_2_pin;            / *     0     8 * /
+	cpumask_var_t              domain;               / *     8    16 * /
+	cpumask_var_t              old_domain;           / *    24    16 * /
+	u8                         vector;               / *    40     1 * /
+	u8                         move_in_progress:1;   / *    41: 7  1 * /
+	u8                         remapped:1;           / *    41: 6  1 * /
+
+	/ * XXX 6 bits hole, try to pack * /
+	/ * XXX 6 bytes hole, try to pack * /
+
+	union {
+		struct irq_2_iommu irq_2_iommu;          / *          16 * /
+		struct irq_2_irte  irq_2_irte;           / *           4 * /
+	};                                               / *    48    16 * /
+	/ *  --- cacheline 1 boundary (64 bytes) --- * /
+
+			 * So just fix it up if the byte_size of the bitfield is
+			 * greater than what it really uses.
+			 */
+			if (real_size < size) {
 				uint16_t new_type_id;
 				struct tag *new_type_tag =
 					cu__find_base_type_of_size(cu,
@@ -750,7 +772,7 @@ static void class__fixup_member_types(struct class *self, const struct cu *cu,
 						__func__, real_size);
 					continue;
 				}
-				class__fixup_bitfield_types(self,
+				class__fixup_bitfield_types(class,
 							    bitfield_head, pos,
 							    new_type_id);
 				fixup_was_done = 1;
@@ -761,37 +783,37 @@ static void class__fixup_member_types(struct class *self, const struct cu *cu,
 	if (verbose && fixup_was_done) {
 		fprintf(fp, "/* bitfield types were fixed */\n");
 		if (verbose > 1) {
-			class__find_holes(self);
-			class__fprintf(self, cu, NULL, fp);
+			class__find_holes(class);
+			class__fprintf(class, cu, fp);
 			fputc('\n', fp);
 		}
 	}
 }
 
-void class__reorganize(struct class *self, const struct cu *cu,
+void class__reorganize(struct class *class, const struct cu *cu,
 		       const int verbose, FILE *fp)
 {
 	struct class_member *member, *brother, *last_member;
 	size_t alignment_size;
 
-	class__fixup_member_types(self, cu, verbose, fp);
+	class__fixup_member_types(class, cu, verbose, fp);
 
-	while (class__demote_bitfields(self, cu, verbose, fp))
-		class__reorganize_bitfields(self, cu, verbose, fp);
+	while (class__demote_bitfields(class, cu, verbose, fp))
+		class__reorganize_bitfields(class, cu, verbose, fp);
 
 	/* Now try to combine holes */
 restart:
 	alignment_size = 0;
-	class__find_holes(self);
+	class__find_holes(class);
 	/*
 	 * It can be NULL if this class doesn't have any data members,
 	 * just inheritance entries
 	 */
-	last_member = type__last_member(&self->type);
+	last_member = type__last_member(&class->type);
 	if (last_member == NULL)
 		return;
 
-	type__for_each_data_member(&self->type, member) {
+	type__for_each_data_member(&class->type, member) {
 		const size_t aligned_size = member->byte_size + member->hole;
 		if (aligned_size <= cu->addr_size &&
 		    aligned_size > alignment_size)
@@ -811,21 +833,21 @@ restart:
 		else
 			new_padding = 0;
 
-		if (new_padding != self->padding) {
-			self->padding	= new_padding;
-			self->type.size = (last_member->byte_offset +
+		if (new_padding != class->padding) {
+			class->padding	= new_padding;
+			class->type.size = (last_member->byte_offset +
 					   last_member->byte_size + new_padding);
 		}
 	}
 
-	type__for_each_data_member(&self->type, member) {
+	type__for_each_data_member(&class->type, member) {
 		/* See if we have a hole after this member */
 		if (member->hole != 0) {
 			/*
 			 * OK, try to find a member that has a hole after it
 			 * and that has a size that fits the current hole:
 			*/
-			brother = class__find_next_hole_of_size(self, member,
+			brother = class__find_next_hole_of_size(class, member,
 								member->hole);
 			if (brother != NULL) {
 				struct class_member *brother_prev =
@@ -839,7 +861,7 @@ restart:
 				 * kernel.
 				 */
 				if (brother_prev != member) {
-					class__move_member(self, member,
+					class__move_member(class, member,
 							   brother, cu, 0,
 							   verbose, fp);
 					goto restart;
@@ -852,11 +874,11 @@ restart:
 			 * we can move it after the current member, reducing
 			 * the padding or eliminating it altogether.
 			 */
-			if (self->padding > 0 &&
+			if (class->padding > 0 &&
 			    member != last_member &&
 			    last_member->byte_size != 0 &&
 			    last_member->byte_size <= member->hole) {
-				class__move_member(self, member, last_member,
+				class__move_member(class, member, last_member,
 						   cu, 1, verbose, fp);
 				goto restart;
 			}
@@ -864,13 +886,13 @@ restart:
 	}
 
 	/* Now try to move members at the tail to after holes */
-	if (self->nr_holes == 0)
+	if (class->nr_holes == 0)
 		return;
 
-	type__for_each_data_member(&self->type, member) {
+	type__for_each_data_member(&class->type, member) {
 		/* See if we have a hole after this member */
 		if (member->hole != 0) {
-			brother = class__find_last_member_of_size(self, member,
+			brother = class__find_last_member_of_size(class, member,
 								  member->hole);
 			if (brother != NULL) {
 				struct class_member *brother_prev =
@@ -884,7 +906,7 @@ restart:
 				 * kernel.
 				 */
 				if (brother_prev != member) {
-					class__move_member(self, member,
+					class__move_member(class, member,
 							   brother, cu, 0,
 							   verbose, fp);
 					goto restart;
