@@ -18,15 +18,15 @@ struct class;
 struct cu;
 struct class_member;
 
-void class__subtract_offsets_from(struct class *self, struct class_member *from,
+void class__subtract_offsets_from(struct class *cls, struct class_member *from,
 				  const uint16_t size);
 
-void class__add_offsets_from(struct class *self, struct class_member *from,
+void class__add_offsets_from(struct class *cls, struct class_member *from,
 			     const uint16_t size);
 
-void class__fixup_alignment(struct class *self, const struct cu *cu);
+void class__fixup_alignment(struct class *cls, const struct cu *cu);
 
-void class__reorganize(struct class *self, const struct cu *cu,
+void class__reorganize(struct class *cls, const struct cu *cu,
 		       const int verbose, FILE *fp);
 
 #endif /* _DWARVES_REORGANIZE_H_ */
